==> mfc-vms-meta-model-0.1.0-sources.jar: com/valor/mfc/vms/meta/model/database/ddo/ui/UIConfgDdo.java <==
package com.valor.mfc.vms.meta.model.database.ddo.ui;

import com.valor.mfc.vms.common.database.model.AbstractLMI;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * Created by Frank.Huang on 2016/11/15.
 */
@Entity
@Table(name = "ui_config")
public class UIConfgDdo extends AbstractLMI{
    @Id
    @Column(name = "ui_ver",length = 16)
    private String uiVer;

    @Id
    @Column(name = "ui_key",length = 32)
    private String uiKey;

    @Column(name = "ui_val",length = 32)
    private String uiVal;

    @Column(name = "min_ver")
    private long minVer;

    @Column(name = "max_ver")
    private long maxVer;

    @Column(name = "ui_only_in_admin", columnDefinition="default 1")
    private int uiOnlyInAdmin;
    @Column(name = "show_seq", columnDefinition = "int(11) default -1 COMMENT '展示顺序，值越高越靠前'")
    private int showSeq;

    public String getUiVer() {
        return uiVer;
    }

    public void setUiVer(String uiVer) {
        this.uiVer = uiVer;
    }

    public String getUiKey() {
        return uiKey;
    }

    public void setUiKey(String uiKey) {
        this.uiKey = uiKey;
    }

    public String getUiVal() {
        return uiVal;
    }

    public void setUiVal(String uiVal) {
        this.uiVal = uiVal;
    }

    public long getMinVer() {
        return minVer;
    }

    public void setMinVer(long minVer) {
        this.minVer = minVer;
    }

    public long getMaxVer() {
        return maxVer;
    }

    public void setMaxVer(long maxVer) {
        this.maxVer = maxVer;
    }

    public int getUiOnlyInAdmin() {
        return uiOnlyInAdmin;
    }

    public void setUiOnlyInAdmin(int uiOnlyInAdmin) {
        this.uiOnlyInAdmin = uiOnlyInAdmin;
    }

    public int getShowSeq() {
        return showSeq;
    }

    public void setShowSeq(int showSeq) {
        this.showSeq = showSeq;
    }
}

==> mfc-vms-meta-model-0.1.15-sources.jar: com/valor/mfc/vms/meta/model/database/ddo/ui/UIConfgDdo.java <==
package com.valor.mfc.vms.meta.model.database.ddo.ui;

import com.valor.mfc.vms.common.database.model.AbstractLMI;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * Created by Frank.Huang on 2016/11/15.
 */
@Entity
@Table(name = "ui_config")
public class UIConfgDdo extends AbstractLMI{
    @Id
    @Column(name = "ui_ver",length = 16)
    private String uiVer;

    @Id
    @Column(name = "ui_key",length = 32)
    private String uiKey;

    @Column(name = "ui_val",length = 32)
    private String uiVal;

    @Column(name = "min_ver")
    private long minVer;

    @Column(name = "max_ver")
    private long maxVer;

    @Column(name = "app_id")
    private String appId;

    @Column(name = "ui_only_in_admin", columnDefinition="default 1")
    private int uiOnlyInAdmin;
    @Column(name = "show_seq", columnDefinition = "int(11) default -1 COMMENT '展示顺序，值越高越靠前'")
    private int showSeq;

    public String getUiVer() {
        return uiVer;
    }

    public void setUiVer(String uiVer) {
        this.uiVer = uiVer;
    }

    public String getUiKey() {
        return uiKey;
    }

    public void setUiKey(String uiKey) {
        this.uiKey = uiKey;
    }

    public String getUiVal() {
        return uiVal;
    }

    public void setUiVal(String uiVal) {
        this.uiVal = uiVal;
    }

    public long getMinVer() {
        return minVer;
    }

    public void setMinVer(long minVer) {
        this.minVer = minVer;
    }

    public long getMaxVer() {
        return maxVer;
    }

    public void setMaxVer(long maxVer) {
        this.maxVer = maxVer;
    }

    public int getUiOnlyInAdmin() {
        return uiOnlyInAdmin;
    }

    public void setUiOnlyInAdmin(int uiOnlyInAdmin) {
        this.uiOnlyInAdmin = uiOnlyInAdmin;
    }

    public int getShowSeq() {
        return showSeq;
    }

    public void setShowSeq(int showSeq) {
        this.showSeq = showSeq;
    }


    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }
}
